@@ -14,43 +14,70 @@ class Logger():
 
     Parameters
     ----------
+    gpu : int
+        gpu id
+    metrics : str
+        metrics string.
+    input_shape : list
+        list containing input shape
     image_loader : torch.utils.data.Dataloader
-        Dataloader object to load image
-    args : dict
-        Arguments dictionary.
+        dataloader object to load image
+    batch_size : int
+        batch size
+    log_dir : str
+        path to log output location
+    dataset_dir : str
+        path to dataset location
+    images_to_be_logged : list
+        list of paths for images to be logged
     polyaxon_exp : poyaxon.tracking.Run
         polyaxon experiment
 
     Attributes
     ----------
-    args
-    polyaxon_exp
-    image_loader
+    gpu : int
+        gpu id
+    metrics : str
+        metrics string.
+    input_shape : list
+        list containing input shape
+    image_loader : torch.utils.data.Dataloader
+        dataloader object to load image
+    batch_size : int
+        batch size
+    log_dir : str
+        path to log output location
+    dataset_dir : str
+        path to dataset location
+    images_to_be_logged : list
+        list of paths for images to be logged
+    polyaxon_exp : poyaxon.tracking.Run
+        polyaxon experiment
 
     """
 
     def __init__(self,
+                 gpu,
+                 metrics,
+                 input_shape,
                  image_loader,
-                 args,
+                 batch_size,
+                 log_dir,
+                 dataset_dir,
+                 images_to_be_logged,
                  polyaxon_exp=None):
-        """Initialises logger object.
-
-        Parameters
-        ----------
-        image_loader : torch.utils.data.Dataloader
-            Dataloader object to load image
-        args : dict
-            Arguments dictionary.
-        polyaxon_exp : poyaxon.tracking.Run
-            polyaxon experiment
-
-        """
-        self.args = args
+        self.gpu = gpu
+        self.metrics = metrics
+        self.input_shape = input_shape
         self.polyaxon_exp = polyaxon_exp
         self.image_loader = image_loader
+        self.batch_size = batch_size
+        self.log_dir = log_dir
+        self.dataset_dir = dataset_dir
         self.metrics = Metrics(polyaxon_exp=polyaxon_exp,
                                phase='log',
-                               metrics_strings=args.metrics)
+                               metrics_strings=self.metrics)
+        self.images_to_be_logged = images_to_be_logged
 
     def _patchify(self, image):
         """fragments image into patches.
@@ -69,7 +96,7 @@ class Logger():
         """
         logging.debug("Enter _patchify routine")
         patches, locs = [], []
-        w = self.args.input_shape[2]
+        w = self.input_shape[2]
         for i in range(0, image.shape[2], w):
             for j in range(0, image.shape[3], w):
                 if i + w <= image.shape[2] and j + w <= image.shape[3]:
@@ -98,7 +125,7 @@ class Logger():
         """
         logging.debug("Enter _unpatchify routine")
         output = np.zeros((shape[0], shape[1]))
-        w = self.args.input_shape[2]
+        w = self.input_shape[2]
         for i in range(len(locs)):
             x, y = locs[i]
             output[x:x + w, y:y + w] = patches[i]
@@ -126,17 +153,17 @@ class Logger():
         """
         logging.debug("Enter predict_and_log routine")
         model.eval()
-        for image_path in self.args.images_to_be_logged:
-            image = self.image_loader(os.path.join(self.args.dataset_dir,
+        for image_path in self.images_to_be_logged:
+            image = self.image_loader(os.path.join(self.dataset_dir,
                                                    image_path))
             shape = [image.shape[2], image.shape[3]]
             patches, locs = self._patchify(image)
 
             result = []
-            for i in range(0, len(patches), self.args.batch_size):
-                batch = torch.tensor(patches[i:i + self.args.batch_size])
-                if self.args.gpu > -1:
-                    batch = batch.to(self.args.gpu)
+            for i in range(0, len(patches), self.batch_size):
+                batch = torch.tensor(patches[i:i + self.batch_size])
+                if self.gpu > -1:
+                    batch = batch.to(self.gpu)
                 preds = model(batch)
                 preds = self.metrics._argmax_or_thresholding(preds).cpu().numpy()
                 result.append(preds.astype(np.uint8))
@@ -151,7 +178,7 @@ class Logger():
                                             step=epoch)
 
             im = Image.fromarray(pred_mask)
-            im.save(os.path.join(self.args.log_dir,
+            im.save(os.path.join(self.log_dir,
                     'epoch_' + str(epoch) + '_' + image_path.replace('/', '_')))
 
         logging.debug("Exit predict_and_log routine")
