@@ -29,8 +29,10 @@ class BCEJaccardLoss(nn.Module):
 
     Parameters
     ----------
-    args : list
-        arguments list.
+    jaccard_weight : float
+        jaccard weight
+    eps : float
+        epsilon
 
     References
     ----------
@@ -40,25 +42,13 @@ class BCEJaccardLoss(nn.Module):
 
     """
 
-    def __init__(self, args):
-        """Initialise loss module.
-
-        Parameters
-        ----------
-        args : list
-            arguments list.
-
-        """
+    def __init__(self, jaccard_weight, eps=1e-15):
         super(BCEJaccardLoss, self).__init__()
-        self.gpu = args.gpu
-
-        if hasattr(args, 'eps'):
-            self.eps = args.eps
-        else:
-            self.eps = 1e-15
+        self.eps = eps
+        self.jaccard_weight = jaccard_weight
 
         self.nll_loss = nn.BCELoss()
-        self.jaccard_weight = args.jaccard_weight
+
         self._stash_bce_loss = 0
         self._stash_jaccard = 0
 
