@@ -34,8 +34,14 @@ class TverskyLoss(nn.Module):
 
     Parameters
     ----------
-    args : type
-        Description of parameter `args`.
+    alpha : float
+        alpha.
+    beta : float
+        beta
+    eps : float
+        epsilon
+    size_average : boolean
+        average size flag
 
     References
     ----------
@@ -43,29 +49,12 @@ class TverskyLoss(nn.Module):
 
     """
 
-    def __init__(self, args):
-        """Initialise loss module.
-
-        Parameters
-        ----------
-        args : list
-            arguments list.
-
-        """
+    def __init__(self, alpha, beta, eps=1e-7, size_average=True):
         super(TverskyLoss, self).__init__()
-        self.alpha = args.alpha
-        self.beta = args.beta
-        self.gpu = args.gpu
-
-        if hasattr(args, 'eps'):
-            self.eps = args.eps
-        else:
-            self.eps = 1e-7
-
-        if hasattr(args, 'size_average'):
-            self.size_average = args.size_average
-        else:
-            self.size_average = True
+        self.alpha = alpha
+        self.beta = beta
+        self.eps = eps
+        self.size_average = size_average
 
     def forward(self, predicted, target):
         """Compute loss between :attr:`predicted` and :attr:`target`.
