@@ -45,8 +45,9 @@ def get_optimizer(key, args, model):
 def set_optimizer(key, optimizer):
     """Allows: 
 
-    1.Addition of a new optimizer to optimizer map
-    2.Modification of existing optimizer definitions in optimizer map
+    * Addition of a new optimizer to optimizer map
+    
+    * Modification of existing optimizer definitions in optimizer map
 
     Parameters
     ----------
